@@ -20,9 +20,13 @@
  * MA 02111-1307, USA.
  */
 
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include "nettle-meta.h"
 
 #include "cast128.h"
 
 const struct nettle_cipher nettle_cast128
-= _NETTLE_CIPHER(cast128, CAST128, 128);
+= _NETTLE_CIPHER_FIX(cast128, CAST128, 128);
