@@ -25,19 +25,22 @@
 
 #if HAVE_CONFIG_H
 # include "config.h"
-#endif /* HAVE_CONFIG_H */
+#endif
 
 /* Openssl glue, for comparative benchmarking only */
 
 #if HAVE_LIBCRYPTO
 
-#include "nettle-internal.h"
+/* No ancient ssleay compatibility */
+#define NCOMPAT
+
+#include <assert.h>
 
 #include <openssl/blowfish.h>
 #include <openssl/des.h>
 #include <openssl/cast.h>
 
-#include <assert.h>
+#include "nettle-internal.h"
 
 
 /* Blowfish */
@@ -93,7 +96,9 @@ static void
 openssl_des_set_key(void *ctx, unsigned length, const uint8_t *key)
 {
   assert(length == 8);
-  des_key_sched((char *) key, ctx);
+  /* Explicit cast used as I don't want to care about openssl's broken
+     array typedefs des_cblock and const_des_cblock. */
+  des_key_sched( (void *) key, ctx);
 }
 
 #define DES_BLOCK_SIZE 8
@@ -105,7 +110,7 @@ openssl_des_encrypt(void *ctx, unsigned length,
   assert (!(length % DES_BLOCK_SIZE));
   while (length)
     {
-      des_ecb_encrypt((char *) src, (char *) dst, ctx, DES_ENCRYPT);
+      des_ecb_encrypt( (void *) src, (void *) dst, ctx, DES_ENCRYPT);
       length -= DES_BLOCK_SIZE;
       dst += DES_BLOCK_SIZE;
       src += DES_BLOCK_SIZE;
@@ -119,7 +124,7 @@ openssl_des_decrypt(void *ctx, unsigned length,
   assert (!(length % DES_BLOCK_SIZE));
   while (length)
     {
-      des_ecb_encrypt((char *) src, (char *) dst, ctx, DES_DECRYPT);
+      des_ecb_encrypt( (void *) src, (void *) dst, ctx, DES_DECRYPT);
       length -= DES_BLOCK_SIZE;
       dst += DES_BLOCK_SIZE;
       src += DES_BLOCK_SIZE;
